@@ -42,6 +42,10 @@ let testable (type a) (pp : a Fmt.t) (equal : a -> a -> bool) : a testable =
   end in
   (module M)
 
+let map f t =
+  let pp ppf = (Fmt.using f (pp t)) ppf and equal a b = equal t (f a) (f b) in
+  testable pp equal
+
 let int32 = testable Fmt.int32 ( = )
 let int64 = testable Fmt.int64 ( = )
 let int = testable Fmt.int ( = )
@@ -78,6 +82,15 @@ let list e =
   in
   testable (Fmt.Dump.list (pp e)) eq
 
+let seq e =
+  let rec eq s1 s2 =
+    match (s1 (), s2 ()) with
+    | Seq.Cons (x, xs), Seq.Cons (y, ys) -> equal e x y && eq xs ys
+    | Nil, Nil -> true
+    | _ -> false
+  in
+  testable (Fmt.Dump.seq (pp e)) eq
+
 let slist (type a) (a : a testable) compare =
   let l = list a in
   let eq l1 l2 = equal l (List.sort compare l1) (List.sort compare l2) in
@@ -250,9 +263,9 @@ let match_raises ?here ?pos msg exnp f =
           Fmt.pf ppf "%t%a %s: got nothing." (pp_location ?here ?pos) Pp.tag
             `Fail msg)
   | Some e ->
-      if exnp e then
+      if not (exnp e) then
         check_err (fun ppf () ->
             Fmt.pf ppf "%t%a %s: got %a." (pp_location ?here ?pos) Pp.tag `Fail
               msg Fmt.exn e)
 
-let skip () = raise Core.Skip
+let skip () = raise Core.V1.Skip
