@@ -74,6 +74,9 @@ val unit : unit testable
 val list : 'a testable -> 'a list testable
 (** [list t] tests lists of [t]s. *)
 
+val seq : 'a testable -> 'a Seq.t testable
+(** [seq t] tests sequence of [t]s. *)
+
 val slist : 'a testable -> ('a -> 'a -> int) -> 'a list testable
 (** [slist t comp] tests sorted lists of [t]s. The list are sorted using [comp]. *)
 
@@ -107,6 +110,9 @@ val neg : 'a testable -> 'a testable
 (** [neg t] is [t]'s negation: it is [true] when [t] is [false] and it is
     [false] when [t] is [true]. *)
 
+val map : ('b -> 'a) -> 'a testable -> 'b testable
+(** [map f t] lift a ['a testable] to a ['b testable], converting ['b] to ['a]. *)
+
 (** {1 Assertion functions}
 
     Functions for asserting various properties within unit-tests. A failing
@@ -152,7 +158,9 @@ val check_raises : (string -> exn -> (unit -> unit) -> unit) extra_info
 
 val match_raises :
   (string -> (exn -> bool) -> (unit -> unit) -> unit) extra_info
-(** Check that an exception is raised. *)
+(** [match_raises msg exception_is_expected f] Runs [f ()], and passes the
+    raised exception to [exception_is_expected]. The check fails when no
+    exception is raised, or [exception_is_expected] returns false. *)
 
 val skip : unit -> 'a
 (** Skip the current test case.
