@@ -1,7 +1,7 @@
 let () =
   let open Alcotest in
   let id () = () in
-  run ~argv:[| ""; "--quick" |] __FILE__
+  run ~argv:[| ""; "--quick-tests" |] __FILE__
     [
       ("test-a", [ test_case "Quick" `Quick id; test_case "Slow" `Slow id ]);
       ("test-b", [ test_case "Slow" `Slow id; test_case "Quick" `Quick id ]);
